Changelog
==========

1.2.1 (2024-10-09)
------------------

- Add Python 3.12 and 3.13 support.


1.2.0 (2022-10-27)
------------------

- Add Python 3.9, 3.10, and 3.11 support.

- Drop Python 3.5 and 3.6 support.

- Colorized pipeline and job status output.


1.1.0 (2020-05-04)
------------------

- Recognize simple hostname:path git URLs (GH: #3).

- Change output format to show pipeline dates and short Git commit IDs instead
  of full Git commit IDs.


1.0.1 (2020-04-29)
------------------

- Fix broken image on PyPI project page.


1.0 (2020-04-29)
----------------

- First public release
